--
-- PostgreSQL database dump
--

-- Dumped from database version 12.1
-- Dumped by pg_dump version 13.1

SET statement_timeout = 0;
SET lock_timeout = 0;
SET idle_in_transaction_session_timeout = 0;
SET client_encoding = 'UTF8';
SET standard_conforming_strings = on;
SELECT pg_catalog.set_config('search_path', '', false);
SET check_function_bodies = false;
SET xmloption = content;
SET client_min_messages = warning;
SET row_security = off;

SET default_tablespace = '';

SET default_table_access_method = heap;

--
-- Name: config; Type: TABLE; Schema: public; Owner: postgres
--

CREATE TABLE public.config (
    component character varying(32) NOT NULL,
    config jsonb NOT NULL,
    tag character varying(32)
);


ALTER TABLE public.config OWNER TO postgres;

--
-- Name: exp_logs; Type: TABLE; Schema: public; Owner: postgres
--

CREATE TABLE public.exp_logs (
    exp_id character varying(255) NOT NULL,
    log_type integer NOT NULL,
    log_text text NOT NULL,
    creation_time timestamp without time zone DEFAULT now()
);


ALTER TABLE public.exp_logs OWNER TO postgres;

--
-- Name: exp_session; Type: TABLE; Schema: public; Owner: postgres
--

CREATE TABLE public.exp_session (
    exp_id character varying(255) NOT NULL,
    filepath character varying(255),
    schedule character varying(80),
    start_time timestamp without time zone,
    end_time timestamp without time zone,
    status character varying(80),
    mins character varying(10),
    hour character varying(10),
    dom character varying(10),
    month character varying(10),
    dow character varying(10),
    context character varying(255),
    year smallint DEFAULT 2020,
    next_run_time timestamp without time zone,
    profile jsonb,
    campaign_id integer,
    resource_id integer
);


ALTER TABLE public.exp_session OWNER TO postgres;

--
-- Name: experiments; Type: TABLE; Schema: public; Owner: postgres
--

CREATE TABLE public.experiments (
    filename character varying(255) NOT NULL,
    data json,
    description text,
    type character varying(64) DEFAULT 'experiment'::character varying NOT NULL,
    creation_time timestamp without time zone DEFAULT now(),
    profile jsonb,
    last_update_time timestamp without time zone DEFAULT now(),
    duration integer DEFAULT 30,
    exclusive boolean DEFAULT true,
    tag character varying(80)
);


ALTER TABLE public.experiments OWNER TO postgres;

--
-- Name: test_campaigns; Type: TABLE; Schema: public; Owner: postgres
--

CREATE TABLE public.test_campaigns (
    id integer NOT NULL,
    title character varying(255) NOT NULL,
    creation_time timestamp without time zone DEFAULT now(),
    status character varying(80) DEFAULT 'active'::character varying NOT NULL,
    status_upd_time timestamp without time zone DEFAULT now(),
    resources jsonb NOT NULL,
    experiments jsonb NOT NULL,
    template_params jsonb,
    start_date date,
    end_date date,
    one_off boolean DEFAULT false
);


ALTER TABLE public.test_campaigns OWNER TO postgres;

--
-- Name: exp_session_schedule; Type: VIEW; Schema: public; Owner: postgres
--

CREATE VIEW public.exp_session_schedule AS
 SELECT a.exp_id,
    a.filepath,
    a.start_time,
    a.end_time,
    a.mins,
    a.hour,
    a.dom,
    a.month,
    a.year,
    a.context,
    a.status,
    ((a.profile -> 'target'::text) ->> 'name'::text) AS target_name,
    b.title AS campaign_title,
    c.duration
   FROM public.exp_session a,
    public.test_campaigns b,
    public.experiments c
  WHERE ((a.campaign_id = b.id) AND ((a.filepath)::text = (c.filename)::text))
  ORDER BY a.start_time DESC;


ALTER TABLE public.exp_session_schedule OWNER TO postgres;

--
-- Name: k8_access_review; Type: TABLE; Schema: public; Owner: postgres
--

CREATE TABLE public.k8_access_review (
    id integer NOT NULL,
    context character varying(255) NOT NULL,
    namespace character varying(255) NOT NULL,
    resource character varying(255) NOT NULL,
    verb character varying(255) NOT NULL,
    allowed boolean NOT NULL,
    creation_time timestamp without time zone DEFAULT now()
);


ALTER TABLE public.k8_access_review OWNER TO postgres;

--
-- Name: k8_access_review_id_seq; Type: SEQUENCE; Schema: public; Owner: postgres
--

CREATE SEQUENCE public.k8_access_review_id_seq
    AS integer
    START WITH 1
    INCREMENT BY 1
    NO MINVALUE
    NO MAXVALUE
    CACHE 1;


ALTER TABLE public.k8_access_review_id_seq OWNER TO postgres;

--
-- Name: k8_access_review_id_seq; Type: SEQUENCE OWNED BY; Schema: public; Owner: postgres
--

ALTER SEQUENCE public.k8_access_review_id_seq OWNED BY public.k8_access_review.id;


--
-- Name: k8s_resources; Type: TABLE; Schema: public; Owner: postgres
--

CREATE TABLE public.k8s_resources (
    id integer NOT NULL,
    parent_id integer,
    context character varying(127) NOT NULL,
    kind character varying(80) NOT NULL,
    name character varying(80) NOT NULL,
    profile jsonb,
    status character varying(80),
    last_updated timestamp without time zone DEFAULT now() NOT NULL
);


ALTER TABLE public.k8s_resources OWNER TO postgres;

--
-- Name: k8s_resources_experiments_full_join_view; Type: VIEW; Schema: public; Owner: postgres
--

CREATE VIEW public.k8s_resources_experiments_full_join_view AS
 SELECT k8s_resources.id,
    k8s_resources.parent_id,
    k8s_resources.context,
    k8s_resources.kind,
    k8s_resources.name,
    k8s_resources.status,
    k8s_resources.last_updated,
    experiments.filename AS exp_filename,
    experiments.profile AS exp_profile,
    (experiments.profile -> 'title'::text) AS exp_title
   FROM (public.k8s_resources
     FULL JOIN public.experiments ON ((((experiments.profile -> 'targets'::text) ->> 0) = (k8s_resources.name)::text)));


ALTER TABLE public.k8s_resources_experiments_full_join_view OWNER TO postgres;

--
-- Name: k8s_resources_experiments_view; Type: VIEW; Schema: public; Owner: postgres
--

CREATE VIEW public.k8s_resources_experiments_view AS
 SELECT a.id,
    a.parent_id,
    a.context,
    a.kind,
    a.name,
    a.profile,
    a.status,
    a.last_updated,
    b.filename,
    (b.profile -> 'title'::text) AS title
   FROM public.k8s_resources a,
    public.experiments b
  WHERE (((b.profile -> 'targets'::text) ->> 0) = (a.name)::text);


ALTER TABLE public.k8s_resources_experiments_view OWNER TO postgres;

--
-- Name: k8s_resources_id_seq; Type: SEQUENCE; Schema: public; Owner: postgres
--

CREATE SEQUENCE public.k8s_resources_id_seq
    AS integer
    START WITH 1
    INCREMENT BY 1
    NO MINVALUE
    NO MAXVALUE
    CACHE 1;


ALTER TABLE public.k8s_resources_id_seq OWNER TO postgres;

--
-- Name: k8s_resources_id_seq; Type: SEQUENCE OWNED BY; Schema: public; Owner: postgres
--

ALTER SEQUENCE public.k8s_resources_id_seq OWNED BY public.k8s_resources.id;


--
-- Name: k8s_resources_view; Type: VIEW; Schema: public; Owner: postgres
--

CREATE VIEW public.k8s_resources_view AS
 SELECT a.id,
    a.parent_id,
    a.context,
    a.kind,
    a.name,
    a.profile,
    a.status,
    a.last_updated,
    b.name AS parent_name,
    b.profile AS parent_profile
   FROM public.k8s_resources a,
    public.k8s_resources b
  WHERE (a.parent_id = b.id);


ALTER TABLE public.k8s_resources_view OWNER TO postgres;

--
-- Name: p2_logs; Type: TABLE; Schema: public; Owner: postgres
--

CREATE TABLE public.p2_logs (
    name character varying(255),
    line character varying(8),
    loglevel character varying(8),
    message text,
    pathname character varying(255),
    creation_time timestamp without time zone DEFAULT now()
);


ALTER TABLE public.p2_logs OWNER TO postgres;

--
-- Name: report_entries; Type: TABLE; Schema: public; Owner: postgres
--

CREATE TABLE public.report_entries (
    id integer NOT NULL,
    report_id integer,
    body jsonb NOT NULL
);


ALTER TABLE public.report_entries OWNER TO postgres;

--
-- Name: report_entries_id_seq; Type: SEQUENCE; Schema: public; Owner: postgres
--

CREATE SEQUENCE public.report_entries_id_seq
    AS integer
    START WITH 1
    INCREMENT BY 1
    NO MINVALUE
    NO MAXVALUE
    CACHE 1;


ALTER TABLE public.report_entries_id_seq OWNER TO postgres;

--
-- Name: report_entries_id_seq; Type: SEQUENCE OWNED BY; Schema: public; Owner: postgres
--

ALTER SEQUENCE public.report_entries_id_seq OWNED BY public.report_entries.id;


--
-- Name: reports; Type: TABLE; Schema: public; Owner: postgres
--

CREATE TABLE public.reports (
    id integer NOT NULL,
    title character varying(80) NOT NULL,
    tag character varying(32) NOT NULL,
    report_type character varying(80) NOT NULL,
    description character varying(255),
    params jsonb,
    creation_time timestamp without time zone DEFAULT now()
);


ALTER TABLE public.reports OWNER TO postgres;

--
-- Name: reports_id_seq; Type: SEQUENCE; Schema: public; Owner: postgres
--

CREATE SEQUENCE public.reports_id_seq
    AS integer
    START WITH 1
    INCREMENT BY 1
    NO MINVALUE
    NO MAXVALUE
    CACHE 1;


ALTER TABLE public.reports_id_seq OWNER TO postgres;

--
-- Name: reports_id_seq; Type: SEQUENCE OWNED BY; Schema: public; Owner: postgres
--

ALTER SEQUENCE public.reports_id_seq OWNED BY public.reports.id;


--
-- Name: resources; Type: TABLE; Schema: public; Owner: postgres
--

CREATE TABLE public.resources (
    id integer NOT NULL,
    parent_id integer,
    kind character varying(80) NOT NULL,
    name character varying(80) NOT NULL,
    profile jsonb,
    creation_time timestamp without time zone DEFAULT now() NOT NULL,
    last_updated timestamp without time zone DEFAULT now() NOT NULL,
    layer character varying(80),
    tag character varying(80),
    status character varying(80) DEFAULT 'active'::character varying
);


ALTER TABLE public.resources OWNER TO postgres;

--
-- Name: resources_id_seq; Type: SEQUENCE; Schema: public; Owner: postgres
--

CREATE SEQUENCE public.resources_id_seq
    AS integer
    START WITH 1
    INCREMENT BY 1
    NO MINVALUE
    NO MAXVALUE
    CACHE 1;


ALTER TABLE public.resources_id_seq OWNER TO postgres;

--
-- Name: resources_id_seq; Type: SEQUENCE OWNED BY; Schema: public; Owner: postgres
--

ALTER SEQUENCE public.resources_id_seq OWNED BY public.resources.id;


--
-- Name: session_report; Type: TABLE; Schema: public; Owner: postgres
--

CREATE TABLE public.session_report (
    exp_id character varying(255) NOT NULL,
    load_injectors boolean,
    test_result boolean,
    notes text,
    target_loaded boolean
);


ALTER TABLE public.session_report OWNER TO postgres;

--
-- Name: session_report_view; Type: VIEW; Schema: public; Owner: postgres
--

CREATE VIEW public.session_report_view AS
 SELECT session.exp_id,
    session.filepath,
    session.schedule,
    session.start_time,
    session.end_time,
    session.status,
    session.mins,
    session.hour,
    session.dom,
    session.month,
    session.dow,
    session.context,
    session.year,
    session.next_run_time,
    session.profile,
    session.campaign_id,
    session.resource_id,
    session_report.load_injectors,
    session_report.test_result,
    session_report.target_loaded
   FROM (public.exp_session session
     LEFT JOIN public.session_report ON (((session.exp_id)::text = (session_report.exp_id)::text)));


ALTER TABLE public.session_report_view OWNER TO postgres;

--
-- Name: sessions_targets; Type: VIEW; Schema: public; Owner: postgres
--

CREATE VIEW public.sessions_targets AS
 SELECT a.exp_id,
    a.filepath,
    a.start_time,
    a.mins,
    a.hour,
    a.month,
    a.dom,
    a.dow,
    a.year,
    a.status,
    a.context,
    (b.profile -> 'target'::text) AS target,
    (b.profile -> 'title'::text) AS title
   FROM public.exp_session a,
    public.experiments b
  WHERE ((a.filepath)::text = (b.filename)::text);


ALTER TABLE public.sessions_targets OWNER TO postgres;

--
-- Name: shifts; Type: TABLE; Schema: public; Owner: postgres
--

CREATE TABLE public.shifts (
    day integer,
    month integer,
    year integer,
    shift_id integer,
    start_hour integer,
    start_minute integer,
    end_hour integer,
    end_minute integer,
    num_sessions_in_shift integer DEFAULT 0,
    tag character varying(127) DEFAULT NULL::character varying
);


ALTER TABLE public.shifts OWNER TO postgres;

--
-- Name: slack_channels; Type: TABLE; Schema: public; Owner: postgres
--

CREATE TABLE public.slack_channels (
    channel character varying(80) NOT NULL,
    url character varying(255)
);


ALTER TABLE public.slack_channels OWNER TO postgres;

--
-- Name: test_campaigns_id_seq; Type: SEQUENCE; Schema: public; Owner: postgres
--

CREATE SEQUENCE public.test_campaigns_id_seq
    AS integer
    START WITH 1
    INCREMENT BY 1
    NO MINVALUE
    NO MAXVALUE
    CACHE 1;


ALTER TABLE public.test_campaigns_id_seq OWNER TO postgres;

--
-- Name: test_campaigns_id_seq; Type: SEQUENCE OWNED BY; Schema: public; Owner: postgres
--

ALTER SEQUENCE public.test_campaigns_id_seq OWNED BY public.test_campaigns.id;


--
-- Name: test_coverage; Type: VIEW; Schema: public; Owner: postgres
--

CREATE VIEW public.test_coverage AS
 SELECT k8s_resources.context,
    k8s_resources.name,
    exp_session.status,
    exp_session.dom AS day,
    exp_session.month,
    exp_session.year
   FROM (public.k8s_resources
     LEFT JOIN public.exp_session ON ((((exp_session.profile -> 'target'::text) ->> 'name'::text) = (k8s_resources.name)::text)))
  WHERE (((k8s_resources.context)::text = 'nbcu-int-nft-useast2'::text) AND ((k8s_resources.kind)::text = 'namespace'::text) AND ((k8s_resources.name)::text ~~ '%int-nft%'::text))
  ORDER BY k8s_resources.name;


ALTER TABLE public.test_coverage OWNER TO postgres;

--
-- Name: k8_access_review id; Type: DEFAULT; Schema: public; Owner: postgres
--

ALTER TABLE ONLY public.k8_access_review ALTER COLUMN id SET DEFAULT nextval('public.k8_access_review_id_seq'::regclass);


--
-- Name: k8s_resources id; Type: DEFAULT; Schema: public; Owner: postgres
--

ALTER TABLE ONLY public.k8s_resources ALTER COLUMN id SET DEFAULT nextval('public.k8s_resources_id_seq'::regclass);


--
-- Name: report_entries id; Type: DEFAULT; Schema: public; Owner: postgres
--

ALTER TABLE ONLY public.report_entries ALTER COLUMN id SET DEFAULT nextval('public.report_entries_id_seq'::regclass);


--
-- Name: reports id; Type: DEFAULT; Schema: public; Owner: postgres
--

ALTER TABLE ONLY public.reports ALTER COLUMN id SET DEFAULT nextval('public.reports_id_seq'::regclass);


--
-- Name: resources id; Type: DEFAULT; Schema: public; Owner: postgres
--

ALTER TABLE ONLY public.resources ALTER COLUMN id SET DEFAULT nextval('public.resources_id_seq'::regclass);


--
-- Name: test_campaigns id; Type: DEFAULT; Schema: public; Owner: postgres
--

ALTER TABLE ONLY public.test_campaigns ALTER COLUMN id SET DEFAULT nextval('public.test_campaigns_id_seq'::regclass);


--
-- Name: config config_pkey; Type: CONSTRAINT; Schema: public; Owner: postgres
--

ALTER TABLE ONLY public.config
    ADD CONSTRAINT config_pkey PRIMARY KEY (component);


--
-- Name: shifts constraint_unique; Type: CONSTRAINT; Schema: public; Owner: postgres
--

ALTER TABLE ONLY public.shifts
    ADD CONSTRAINT constraint_unique UNIQUE (day, month, year, shift_id, tag);


--
-- Name: exp_session exp_session_pkey; Type: CONSTRAINT; Schema: public; Owner: postgres
--

ALTER TABLE ONLY public.exp_session
    ADD CONSTRAINT exp_session_pkey PRIMARY KEY (exp_id);


--
-- Name: experiments experiments_pkey; Type: CONSTRAINT; Schema: public; Owner: postgres
--

ALTER TABLE ONLY public.experiments
    ADD CONSTRAINT experiments_pkey PRIMARY KEY (filename, type);


--
-- Name: k8_access_review k8_access_review_context_namespace_resource_verb_key; Type: CONSTRAINT; Schema: public; Owner: postgres
--

ALTER TABLE ONLY public.k8_access_review
    ADD CONSTRAINT k8_access_review_context_namespace_resource_verb_key UNIQUE (context, namespace, resource, verb);


--
-- Name: k8_access_review k8_access_review_pkey; Type: CONSTRAINT; Schema: public; Owner: postgres
--

ALTER TABLE ONLY public.k8_access_review
    ADD CONSTRAINT k8_access_review_pkey PRIMARY KEY (id);


--
-- Name: k8s_resources k8s_resources_context_kind_name_unique; Type: CONSTRAINT; Schema: public; Owner: postgres
--

ALTER TABLE ONLY public.k8s_resources
    ADD CONSTRAINT k8s_resources_context_kind_name_unique UNIQUE (context, kind, name);


--
-- Name: k8s_resources k8s_resources_pkey; Type: CONSTRAINT; Schema: public; Owner: postgres
--

ALTER TABLE ONLY public.k8s_resources
    ADD CONSTRAINT k8s_resources_pkey PRIMARY KEY (id);


--
-- Name: reports reports_pkey; Type: CONSTRAINT; Schema: public; Owner: postgres
--

ALTER TABLE ONLY public.reports
    ADD CONSTRAINT reports_pkey PRIMARY KEY (id);


--
-- Name: resources resources_pkey; Type: CONSTRAINT; Schema: public; Owner: postgres
--

ALTER TABLE ONLY public.resources
    ADD CONSTRAINT resources_pkey PRIMARY KEY (id);


--
-- Name: session_report session_report_exp_id_key; Type: CONSTRAINT; Schema: public; Owner: postgres
--

ALTER TABLE ONLY public.session_report
    ADD CONSTRAINT session_report_exp_id_key UNIQUE (exp_id);


--
-- Name: slack_channels slack_channels_pkey; Type: CONSTRAINT; Schema: public; Owner: postgres
--

ALTER TABLE ONLY public.slack_channels
    ADD CONSTRAINT slack_channels_pkey PRIMARY KEY (channel);


--
-- Name: test_campaigns test_campaigns_pkey; Type: CONSTRAINT; Schema: public; Owner: postgres
--

ALTER TABLE ONLY public.test_campaigns
    ADD CONSTRAINT test_campaigns_pkey PRIMARY KEY (id);


--
-- Name: exp_logs exp_logs_exp_id_fkey; Type: FK CONSTRAINT; Schema: public; Owner: postgres
--

ALTER TABLE ONLY public.exp_logs
    ADD CONSTRAINT exp_logs_exp_id_fkey FOREIGN KEY (exp_id) REFERENCES public.exp_session(exp_id) ON DELETE CASCADE;


--
-- Name: exp_session exp_session_campaign_id_fkey; Type: FK CONSTRAINT; Schema: public; Owner: postgres
--

ALTER TABLE ONLY public.exp_session
    ADD CONSTRAINT exp_session_campaign_id_fkey FOREIGN KEY (campaign_id) REFERENCES public.test_campaigns(id);


--
-- Name: exp_session exp_session_resource_id_fkey; Type: FK CONSTRAINT; Schema: public; Owner: postgres
--

ALTER TABLE ONLY public.exp_session
    ADD CONSTRAINT exp_session_resource_id_fkey FOREIGN KEY (resource_id) REFERENCES public.resources(id) ON DELETE CASCADE;


--
-- Name: report_entries report_entries_report_id_fkey; Type: FK CONSTRAINT; Schema: public; Owner: postgres
--

ALTER TABLE ONLY public.report_entries
    ADD CONSTRAINT report_entries_report_id_fkey FOREIGN KEY (report_id) REFERENCES public.reports(id) ON DELETE CASCADE;


--
-- Name: resources resources_parent_id_fkey; Type: FK CONSTRAINT; Schema: public; Owner: postgres
--

ALTER TABLE ONLY public.resources
    ADD CONSTRAINT resources_parent_id_fkey FOREIGN KEY (parent_id) REFERENCES public.resources(id);


--
-- Name: session_report session_report_exp_id_fkey; Type: FK CONSTRAINT; Schema: public; Owner: postgres
--

ALTER TABLE ONLY public.session_report
    ADD CONSTRAINT session_report_exp_id_fkey FOREIGN KEY (exp_id) REFERENCES public.exp_session(exp_id) ON DELETE CASCADE;


--
-- PostgreSQL database dump complete
--

