#!/usr/bin/env python
import os
import unittest
from datetime import date
from pprint import pprint

from p2.tools.json import serializable
from p2.tools.packages import get_p2_packages

class CustomObj:

    def __init__(self, name, date, children:list=None):
        self.name='custom object'
        self.date=date
        self.children=children

class TestP2_tools(unittest.TestCase):

    def test_json_serializable(self):
        d = {'date': date(year=2021, month=3, day=24), 'anything_else': 'rest the same'}
        d_serializable = serializable(d)
        self.assertEqual(d_serializable['date'], '2021-03-24')
        self.assertEqual(d_serializable['anything_else'], 'rest the same')

        obj = CustomObj(
            name='obj 1',
            date=date(year=2021, month=3, day=24),
            children=[CustomObj(name='obj 2', date=date(year=2021, month=3, day=24))]
        )

        d_s = serializable(obj.__dict__)
        self.assertEqual(d_s['date'], '2021-03-24')

    def test_get_p2_packages(self):
        packages = get_p2_packages()
        self.assertIsNotNone(packages)
        self.assertGreater(len(packages), -1)
        pprint(packages)

if __name__ == '__main__':
    import xmlrunner
    runner = xmlrunner.XMLTestRunner(output='test-reports')
    unittest.main(testRunner=runner)
    unittest.main()
